@@ -1,6 +1,6 @@
 package ClearCase::Argv;
 
-$VERSION = '1.16';
+$VERSION = '1.17';
 
 use Argv 1.09;
 
@@ -699,6 +699,15 @@ attribute. Verbosity styles are as follows:
     +> pwv			# CtCmd
     -->> pwv			# IPC::ClearTool
 
+A final note on these two: turning on one mode will automatically, and
+silently, turn off the other. I.e. the sequence
+
+    ClearCase::Argv->ipc(2);
+    ClearCase::Argv->ctcmd(2);
+
+will not throw any exceptions and will leave you in CtCmd mode. The
+coprocess will be shut down.
+
 =head1 FUNCTIONAL INTERFACE
 
 For those who don't like OO style, or who want to convert existing
